summaryrefslogtreecommitdiffstats
path: root/module/zfs/spa_stats.c
diff options
context:
space:
mode:
authorAlek P <[email protected]>2017-09-29 15:58:52 -0700
committerBrian Behlendorf <[email protected]>2017-09-29 15:58:52 -0700
commit01ff0d7540b21c461c19b90b1e715df26cba3ff2 (patch)
tree72ba39c82ee2a232b878d9edf51bb2812fbe467f /module/zfs/spa_stats.c
parente71cade67d48495db46fb6eed29b88b895bcb2d8 (diff)
Update the default for zfs_txg_history
It's often useful to have access to txg history for debugging purposes. This patch changes the default from 0 to 100 TXGs worth of history preserved. Reviewed by: Matthew Ahrens <[email protected]> Reviewed-by: Giuseppe Di Natale <[email protected]> Reviewed-by: Brian Behlendorf <[email protected]> Reviewed by: Richard Elling <[email protected]> Reviewed by: Prakash Surya <[email protected]> Reviewed-by: George Melikov <[email protected]> Signed-off-by: Alek Pinchuk <[email protected]> Closes #6691
Diffstat (limited to 'module/zfs/spa_stats.c')
-rw-r--r--module/zfs/spa_stats.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/module/zfs/spa_stats.c b/module/zfs/spa_stats.c
index 8c4dba29e..3eeb83a50 100644
--- a/module/zfs/spa_stats.c
+++ b/module/zfs/spa_stats.c
@@ -34,9 +34,9 @@ int zfs_read_history = 0;
int zfs_read_history_hits = 0;
/*
* Keeps stats on the last N txgs, disabled by default.
*/
-int zfs_txg_history = 0;
+int zfs_txg_history = 100;
/*
* Keeps stats on the last N MMP updates, disabled by default.
@@ -34,9 +34,9 @@ int zfs_read_history = 0;
int zfs_read_history_hits = 0;
/*
- * Keeps stats on the last N txgs, disabled by default.
+ * Keeps stats on the last 100 txgs by default.
*/